maxBoardCapacity constant
int
const maxBoardCapacity
Max characters that could flip simultaneously on a full board.
Implementation
static const int maxBoardCapacity = 450;
Max characters that could flip simultaneously on a full board.
static const int maxBoardCapacity = 450;