split_flap_row library
Classes
- SplitFlapRow
- A high-performance row of split-flap units that uses Shared Sprite Sheets (textures). This is the most stable and performant method for Flutter Web CanvasKit/WASM. It creates ONE single sprite sheet per size to avoid engine context loss crashes.
- SplitFlapRowPainter