SplitFlapRow class

A high-performance row of split-flap units that uses Shared Sprite Sheets (textures). This is the most stable and performant method for Flutter Web CanvasKit/WASM. It creates ONE single sprite sheet per size to avoid engine context loss crashes.

Inheritance

Constructors

SplitFlapRow({Key? key, required String text, int maxLength = 10, double unitWidth = 20, double unitHeight = 34, double spacing = 2, Color flapColor = const Color(0xFF161616), Color textColor = Colors.white, Duration flipDuration = const Duration(milliseconds: 75), bool silent = false})
const

Properties

flapColor Color
final
flipDuration Duration
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxLength int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
silent bool
final
spacing double
final
text String
final
textColor Color
final
unitHeight double
final
unitWidth double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SplitFlapRow>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited